@@ -4,8 +4,10 @@ def intify(s):
     """Coerce string to int"""
     return int(re.sub("[^0-9]", "", s))
 
-def tryelse(func, default=None):
+def tryelse(func, default='', exception=Exception):
+    """
+    """
     try:
         return func()
-    except Exception as e:
+    except exception as e:
         return default
